@@ -370,3 +370,36 @@ class FOFOtherRecordStatus(ReadableEnum):
     """FOF其他记录状态"""
     IN = 1
     OUT = 2
+
+
+class FOFSaleStatue(ReadableEnum):
+    """FOF产品状态"""
+    COLLECTION = 1          # 募集期
+    OPEN = 2                # 开放期
+    LOCK = 3                # 锁定期
+    CLEAR = 4               # 已清算
+
+
+class FOFStrategyType(ReadableEnum):
+    """FOF产品 策略类型"""
+    S1 = 1                  # 主观多头
+    S2 = 2                  # 指数增强
+    S3 = 3                  # 市场中性
+    S4 = 4                  # 管理期货
+    S5 = 5                  # 事件驱动
+    S6 = 6                  # 宏观对冲
+    S7 = 7                  # 高频套利
+    S8 = 8                  # 债券策略
+    S9 = 9                  # 期权策略
+    S10 = 10                # 组合策略
+    S11 = 11                # 其他
+    S12 = 12                # 股票中性
+
+
+class FOFRiskType(ReadableEnum):
+    """FOF产品 风险等级"""
+    R1 = 1
+    R2 = 2
+    R3 = 3
+    R4 = 4
+    R5 = 5
