@@ -1193,6 +1193,21 @@ class BasicDataApi(metaclass=Singleton):
             except Exception as e:
                 print(f'failed to get_fof_account_statement <err_msg> {e} from {FOFAccountStatement.__tablename__}')
 
+    def delete_fof_account_statement(self, date_to_delete: datetime.date, fof_id_list: List[str]) -> bool:
+        with BasicDatabaseConnector().managed_session() as session:
+            try:
+                session.query(
+                    FOFAccountStatement
+                ).filter(
+                    FOFAccountStatement.fof_id.in_(fof_id_list),
+                    FOFAccountStatement.datetime == date_to_delete,
+                ).delete(synchronize_session=False)
+                session.commit()
+                return True
+            except Exception as e:
+                print(f'failed to delete data <err_msg> {e} from {FOFAccountStatement.__tablename__}')
+                return False
+
     def get_fof_incidental_statement(self, fof_id_list: Tuple[str] = ()):
         with BasicDatabaseConnector().managed_session() as db_session:
             try:
@@ -1221,6 +1236,21 @@ class BasicDataApi(metaclass=Singleton):
             except Exception as e:
                 print(f'failed to get_fof_manually <err_msg> {e} from {FOFInvestorPosition.__tablename__}')
 
+    def delete_fof_investor_position(self, fof_id_to_delete: datetime.date, investor_id_list: List[str]) -> bool:
+        with BasicDatabaseConnector().managed_session() as session:
+            try:
+                session.query(
+                    FOFInvestorPosition
+                ).filter(
+                    FOFInvestorPosition.investor_id.in_(investor_id_list),
+                    FOFInvestorPosition.fof_id == fof_id_to_delete,
+                ).delete(synchronize_session=False)
+                session.commit()
+                return True
+            except Exception as e:
+                print(f'failed to delete data <err_msg> {e} from {FOFInvestorPosition.__tablename__}')
+                return False
+
     def get_fof_estimate_fee(self, fof_id_list: Tuple[str] = ()):
         with BasicDatabaseConnector().managed_session() as db_session:
             try:
