@@ -38,6 +38,7 @@ from ..raw.raw_data_helper import RawDataHelper
 class DerivedDataProcessor:
     def __init__(self):
         self._data_helper = DerivedDataHelper()
+        self._raw_data_helper = RawDataHelper()
         self.fund_indicator_processor = FundIndicatorProcessor(self._data_helper)
         self.fund_indicator_processor_weekly = FundIndicatorProcessorWeekly(self._data_helper)
         self.fund_indicator_processor_monthly = FundIndicatorProcessorMonthly(self._data_helper)
@@ -72,7 +73,7 @@ class DerivedDataProcessor:
         self._gf_sec_portfolio_processor = GFSecPortfolioProcessor(self._data_helper)
         self._manually_crawled_portfolio_processor = ManuallyCrawledPortfolioProcessor(self._data_helper)
         self._manager_processor_dev = ManagerProcessorDev(self._data_helper)
-        self._oversea_fund_nav_analysis = OverseaFundNavAnalysis(data_helper=RawDataHelper())
+        self._oversea_fund_nav_analysis = OverseaFundNavAnalysis(data_helper=self._raw_data_helper)
 
     def process_all(self, start_date, end_date):
         failed_tasks = []
@@ -130,7 +131,7 @@ class DerivedDataProcessor:
                 else:
                     failed_tasks.extend(self.fund_indicator_processor_monthly.process(start_date, end_date, end_date_dt))
                     failed_tasks.extend(self._manager_processor_dev.process(end_date))
-                    failed_tasks.extend(self._oversea_fund_nav_analysis.monthly_prcess())
+                    failed_tasks.extend(self._oversea_fund_nav_analysis.monthly_prcess(end_date))
 
         except Exception as e:
             print(e)
@@ -139,6 +140,9 @@ class DerivedDataProcessor:
         return failed_tasks
 
     def get_updated_count(self):
+        _dic = self._raw_data_helper._updated_count
+        for k,v in _dic.items():
+            self._data_helper._updated_count[k] = v
         return self._data_helper._updated_count
 
 
