@@ -125,10 +125,9 @@ class IndexValProcessLongTerm:
         except Exception as e:
             print(e)
             traceback.print_exc()
-            failed_tasks.append('index_val')
-
+            failed_tasks.append('index_val_long_term')
         return failed_tasks
 
 
 if __name__ == "__main__":
-    IndexValProcessLongTerm(DerivedDataHelper()).process('20200727', '20200727')
+    IndexValProcessLongTerm(DerivedDataHelper()).process('20210101', '20210222')
