@@ -315,7 +315,7 @@ class FundIndicatorProcessor(object):
             index_ret = self.index_ret[[index_id]]
             for fund_id in fund_list:
                 result.append(self._process_fund_indicator_update(fund_id, time_range, fund_ret, index_id, index_ret))
-            print(f'index {index_id} finish')
+            print(f'index {index_id} finish fund number fund_list {len(fund_list)} fund_list_1 {len(fund_list_1)} fund_list_2 {len(fund_list_2)}')
             for fund_id in fund_list:
                 fund_index_dict[fund_id] = index_id
         result = [ _ for _ in result if not _ is None]
