@@ -21,7 +21,7 @@ from ...view.derived_models import FundManagerInfo, FundManagerIndex, FundManage
 from .derived_data_helper import DerivedDataHelper, normalize, score_rescale
 from ...manager.fund_info_filter import EHR_PROBLEM_EKYWORDS
 
-class ManagerProcessor:
+class ManagerProcessorDev:
 
     #INDEX_LIST = {'csi_boodfund': 'H11023.CSI', 'csi_f_hybrid': 'H11022.CSI', 'csi_f_qdii': 'H11026.CSI', 'csi_stockfund': 'H11021.CSI', 'mmf': 'H11025.CSI','hs300':'hs300'}
     #REPLACE_DICT = {'stock': 'H11021.CSI', 'bond': 'H11023.CSI', 'mmf': 'H11025.CSI', 'QDII': 'H11026.CSI', 'index': 'hs300'}
@@ -301,7 +301,7 @@ class ManagerProcessor:
 
             _idx = fund_manager_list.index(m_id)
             _t1 = time.time()
-            print(f'm_id {m_id} {_idx} {len(fund_manager_list)} cost time {_t1 - _t0}')
+            #print(f'm_id {m_id} {_idx} {len(fund_manager_list)} cost time {_t1 - _t0}')
         t1 = time.time()
         print(f'total cost {t1 - t0}')
         for fund_type in self.FUND_CLASSIFIER:
@@ -473,7 +473,7 @@ class ManagerProcessor:
         _mng_index = self.fund_type_df[mng_id]
         mng_result.update({'mdd~history_daily': 1 - (_mng_index / _mng_index.cummax()).min()})
         _t1 = time.time()
-        print(f'{mng_id} {idx} / {len(self.type_manager_list)} cost time {_t1 - _t0}')
+        #print(f'{mng_id} {idx} / {len(self.type_manager_list)} cost time {_t1 - _t0}')
         return mng_result
 
     def calc_mng_indicator(self):
@@ -569,33 +569,27 @@ class ManagerProcessor:
         name = 'mng_indicator_score'
         self.manager_indicator_score.to_parquet(f'{_s3_bucket_uri}/{name}.parquet', compression='gzip')
 
+    def process(self, end_date):
+        failed_tasks = []
+        try:
+            start_date = '2005-01-01'
+            self.init(start_date=start_date,end_date=end_date,is_mng_index=True)
+            self.calc_index()
+            self.calc_mng_indicator()
+            self.calc_score()
+            self.to_s3()
+        except Exception as e:
+            print(e)
+            traceback.print_exc()
+            failed_tasks.append('manager_indicator_score')
+        return failed_tasks
+
 if __name__ == '__main__':
-    self = ManagerProcessor(DerivedDataApi())
+    self = ManagerProcessorDev(DerivedDataApi())
     start_date = '2005-01-01'
     end_date = '2020-10-31'
     self.init(start_date=start_date,end_date=end_date,is_mng_index=True)
     self.calc_index()
-    
-    bucket_name = 'tl-fund-dm'
-    _s3_bucket_uri: str = f's3://{bucket_name}/dm'
-
-    name = 'mng_best_fund'
-    data = self.mng_best_fund
-    res_dict = {}
-    for k, df in data.items():
-        res_dict[k] = df.to_dict('index')
-    df = pd.DataFrame(res_dict)    
-    df.to_parquet(f'{_s3_bucket_uri}/{name}.parquet', compression='gzip')
-
-    name = 'mng_index_list'
-    data = self.mng_index_list
-    res_dict = {}
-    for k, df in data.items():
-        res_dict[k] = df.to_dict('index')
-    df = pd.DataFrame(res_dict)    
-    df.to_parquet(f'{_s3_bucket_uri}/{name}.parquet', compression='gzip')
-
     self.calc_mng_indicator()
     self.calc_score()
-    name = 'mng_indicator_score'
-    self.manager_indicator_score.to_parquet(f'{_s3_bucket_uri}/{name}.parquet', compression='gzip')
\ No newline at end of file
+    self.to_s3()
\ No newline at end of file
