@@ -14,7 +14,7 @@ class RawDataDownloader:
         # self.rq_downloader = RqRawDataDownloader(rq_license, self._data_helper)
         self.web_downloader = WebRawDataDownloader(self._data_helper)
         self.em_downloader = EmRawDataDownloader(self._data_helper)
-        self.oversea_download = OverseaDataUpdate(update_period=10, data_per_page=5)
+        self.oversea_download = OverseaDataUpdate(update_period=10, data_per_page=5, data_helper=self._data_helper)
         
     def download(self, start_date, end_date):
         failed_tasks = []
