@@ -280,9 +280,9 @@ class HedgeFundNAVReader:
 
 if __name__ == '__main__':
     try:
-        email_data_dir = os.environ['EMAIL_DATA_DIR']
-        user_name = os.environ['EMAIL_USER_NAME']
-        password = os.environ['EMAIL_PASSWORD']
+        email_data_dir = os.environ['SURFING_EMAIL_DATA_DIR']
+        user_name = os.environ['SURFING_EMAIL_USER_NAME']
+        password = os.environ['SURFING_EMAIL_PASSWORD']
     except KeyError as e:
         import sys
         sys.exit(f'can not found enough params in env (e){e}')
