@@ -40,6 +40,7 @@ class SectorInfo(Base):
     main_index_id = Column(CHAR(16), nullable=False)  # 板块代表指数
     main_fund_id = Column(CHAR(16))  # 板块代表基金
 
+
 class SectorFunds(Base):
     '''板块基金表'''
 
@@ -891,6 +892,10 @@ class FOFInfo(FOFBase):
     adjusted_net_value = Column(DOUBLE(asdecimal=False))  # 复权净值
     is_calculating = Column(BOOLEAN, default=False)       # 是否正在计算
     latest_cal_date = Column(DATETIME)                      # 最新净值日
+    strategy_type = Column(Integer)                         # 策略类型
+    risk_type = Column(Integer)                             # 风险等级
+    is_on_sale = Column(BOOLEAN, default=False)             # 是否上架
+    sale_status = Column(Integer)                           # 状态
 
 
 class FOFScaleAlteration(FOFBase):
@@ -909,7 +914,6 @@ class FOFScaleAlteration(FOFBase):
     nav = Column(DOUBLE(asdecimal=False))  # 交易净值
     status = Column(Integer, nullable=False)  # 状态：在途/完成
     event_type = Column(Integer)                            # 交易类型
-    unit_total = Column(DOUBLE(asdecimal=False))  # 确认份额
     asset_type = Column(Enum(HoldingAssetType), nullable=False)  # 资产类型
 
 
@@ -931,7 +935,6 @@ class FOFAssetAllocation(FOFBase):
     confirmed_date = Column(DATE)                                   # 确认日期
     deposited_date = Column(DATE)                                   # 交割日期
     event_type = Column(Integer)                                    # 事件类型
-    unit_total = Column(DOUBLE(asdecimal=False))                    # 确认份额
     water_line = Column(DOUBLE(asdecimal=False))                    # 水位线(累计净值)
     remark = Column(VARCHAR(255))                                   # 备注
 
@@ -961,7 +964,7 @@ class FOFInvestorInfo(Base):
 
 
 class FOFInvestorPosition(FOFBase):
-    '''fof投资人持仓信息'''
+    '''fof投资人持仓信息(最新快照)'''
 
     __tablename__ = 'fof_investor_position'
 
@@ -970,8 +973,27 @@ class FOFInvestorPosition(FOFBase):
     datetime = Column(DATE, primary_key=True)  # 日期
     v_nav = Column(DOUBLE(asdecimal=False))  # 对应到投资人的虚拟净值
     cost_nav = Column(DOUBLE(asdecimal=False))  # 投资人的平均成本
+    mv = Column(DOUBLE(asdecimal=False))  # 总市值
     amount = Column(DOUBLE(asdecimal=False))  # 总投资额
     shares = Column(DOUBLE(asdecimal=False))  # 总份额
+    total_ret = Column(DOUBLE(asdecimal=False))  # 累计收益
+    details = Column(TEXT)  # 持仓详细信息
+
+
+class FOFInvestorPositionSummary(FOFBase):
+    '''fof投资人持仓信息'''
+
+    __tablename__ = 'fof_investor_position_summary'
+
+    investor_id = Column(CHAR(16), primary_key=True)  # 投资人ID
+    datetime = Column(DATE, primary_key=True)  # 日期
+    mv = Column(DOUBLE(asdecimal=False))  # 总市值(总资产)
+    amount = Column(DOUBLE(asdecimal=False))  # 总投资额(总本金)
+    left_amount = Column(DOUBLE(asdecimal=False))  # 剩余本金
+    shares = Column(DOUBLE(asdecimal=False))  # 总份额
+    left_shares = Column(DOUBLE(asdecimal=False))  # 剩余份额
+    total_ret = Column(DOUBLE(asdecimal=False))  # 累计收益
+    total_rr = Column(DOUBLE(asdecimal=False))  # 累计收益率
 
 
 class FOFIncidentalStatement(FOFBase):
