@@ -1,8 +1,11 @@
+
+import datetime
+
 from sqlalchemy import CHAR, Column, Integer, Index, BOOLEAN, text, TEXT, Enum
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.dialects.mysql import DOUBLE, DATE, DATETIME, SMALLINT
 
-from ...constant import StockFactorType, IndClassType
+from ...constant import StockFactorType, IndClassType, HoldingAssetType
 
 
 class Base:
@@ -10,8 +13,8 @@ class Base:
 
 
 class FOFBase:
-    create_time = Column(DATETIME, nullable=False, server_default=text('CURRENT_TIMESTAMP'))  # 创建时间
-    update_time = Column(DATETIME, nullable=False, server_default=text('CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP'))  # 更新时间
+    create_time = Column(DATETIME, nullable=False, default=datetime.datetime.now)  # 创建时间
+    update_time = Column(DATETIME, nullable=False, default=datetime.datetime.now, onupdate=datetime.datetime.now)  # 更新时间
     is_deleted = Column(BOOLEAN, nullable=False, server_default=text('FALSE'))  # 是否删除 默认不删除
 
 
@@ -701,14 +704,14 @@ class FOFNav(FOFBase):
 
     __tablename__ = 'fof_nav'
 
-    fof_id = Column(CHAR(16), primary_key=True)  # 产品ID
-    datetime = Column(DATE, primary_key=True)  # 日期
-    nav = Column(DOUBLE(asdecimal=False), nullable=False)  # 单位净值
-    volume = Column(DOUBLE(asdecimal=False))            # 份额
-    cost = Column(DOUBLE(asdecimal=False))              # 成本
-    mv = Column(DOUBLE(asdecimal=False))                # 市值
-    income = Column(DOUBLE(asdecimal=False))            # 累计收益
-    income_rate = Column(DOUBLE(asdecimal=False))       # 累计收益率
+    fof_id = Column(CHAR(16), primary_key=True)             # 产品ID
+    datetime = Column(DATE, primary_key=True)               # 日期
+    nav = Column(DOUBLE(asdecimal=False), nullable=False)   # 单位净值
+    acc_net_value = Column(DOUBLE(asdecimal=False))         # 累计净值
+    adjusted_nav = Column(DOUBLE(asdecimal=False))          # 复权净值
+    volume = Column(DOUBLE(asdecimal=False))                # 份额
+    mv = Column(DOUBLE(asdecimal=False))                    # 市值
+    ret = Column(DOUBLE(asdecimal=False))                   # 累计收益率
 
 
 class FOFNavPublic(FOFBase):
@@ -716,18 +719,17 @@ class FOFNavPublic(FOFBase):
 
     __tablename__ = 'fof_nav_public'
 
-    fof_id = Column(CHAR(16), primary_key=True)  # 产品ID
-    datetime = Column(DATE, primary_key=True)  # 日期
-    nav = Column(DOUBLE(asdecimal=False), nullable=False)  # 单位净值
-    volume = Column(DOUBLE(asdecimal=False))            # 份额
-    cost = Column(DOUBLE(asdecimal=False))              # 成本
-    mv = Column(DOUBLE(asdecimal=False))                # 市值
-    income = Column(DOUBLE(asdecimal=False))            # 累计收益
-    income_rate = Column(DOUBLE(asdecimal=False))       # 累计收益率
+    fof_id = Column(CHAR(16), primary_key=True)             # 产品ID
+    datetime = Column(DATE, primary_key=True)               # 日期
+    nav = Column(DOUBLE(asdecimal=False), nullable=False)   # 单位净值
+    acc_net_value = Column(DOUBLE(asdecimal=False))         # 累计净值
+    volume = Column(DOUBLE(asdecimal=False))                # 份额
+    mv = Column(DOUBLE(asdecimal=False))                    # 市值
+    ret = Column(DOUBLE(asdecimal=False))                   # 累计收益率
 
 
 class FOFPosition(FOFBase):
-    '''fof持仓数据'''
+    '''fof持仓汇总数据'''
 
     __tablename__ = 'fof_position'
 
@@ -736,3 +738,33 @@ class FOFPosition(FOFBase):
     position = Column(TEXT, nullable=False)  # 持仓信息
     total_current = Column(DOUBLE(asdecimal=False))            # 流动性资产及负债总计
 
+
+class FOFInvestorData(FOFBase):
+    '''fof投资人数据'''
+
+    __tablename__ = 'fof_investor_data'
+
+    fof_id = Column(CHAR(16), primary_key=True)  # 产品ID
+    investor_id = Column(CHAR(16), primary_key=True)  # 客户合同号(投资人ID)
+    total_investment = Column(DOUBLE(asdecimal=False))  # 总投资额
+
+
+class FOFPositionDetail(FOFBase):
+    '''fof持仓详细数据'''
+
+    __tablename__ = 'fof_position_detail'
+
+    fof_id = Column(CHAR(16), primary_key=True)  # 产品ID
+    datetime = Column(DATE, primary_key=True)  # 日期
+    fund_id = Column(CHAR(10), primary_key=True) # 基金ID
+    asset_type = Column(Enum(HoldingAssetType), nullable=False)  # 资产类型
+    confirmed_nav = Column(TEXT, nullable=False)  # 确认日净值列表
+    water_line = Column(TEXT, nullable=False)  # 水位线列表(累计净值)
+    nav = Column(DOUBLE(asdecimal=False), nullable=False)  # 单位净值
+    v_nav = Column(DOUBLE(asdecimal=False))  # 虚拟净值
+    acc_nav = Column(DOUBLE(asdecimal=False), nullable=False)  # 累计净值
+    total_shares = Column(DOUBLE(asdecimal=False), nullable=False)  # 总份额
+    total_cost = Column(DOUBLE(asdecimal=False), nullable=False)  # 投资成本
+    latest_mv = Column(DOUBLE(asdecimal=False), nullable=False)  # 当日市值
+    total_ret = Column(DOUBLE(asdecimal=False), nullable=False)  # 累计收益
+    total_rr = Column(DOUBLE(asdecimal=False), nullable=False)  # 累计收益率
