@@ -216,7 +216,7 @@ class ReportHelper:
         w = self._calc_stat(self.fund_mv.copy())
         return w
 
-    def get_last_position(self,asset_target,result):
+    def get_last_position(self,asset_target,result,dm):
         last_date = list(self.fund_position_history.keys())[-1]
         last_rebalance_dt = max(list(result['hold_years'].keys()))
         last_rebalance_dt = pd.to_datetime(last_rebalance_dt).date()
@@ -311,12 +311,15 @@ class ReportHelper:
         pct_cols = ['weight','fund_rank_pct','cur_index_weight','target_index_weight','cur_index_mdd','cur_fund_mdd','fund_ex_index_ret_rate_recent_1m','relative_mdd','index_weight_diff']
         for pct_col in pct_cols:
             pos_df[pct_col] = pos_df[pct_col].map(lambda x:str(round(x*100,1))+'%')
+        fund_id_list = pos_df.fund_id.tolist()
+        _df = dm.view_data(func_name='get_daily_fund_daily_result', fund_id_list=fund_id_list).rename(columns={'基金ID':'fund_id'}).set_index('fund_id')
         df_cols_order = ['fund_id','index_id', 'weight', 'desc_name', 'fund_manager',
                  'fund_rank', 'fund_rank_pct','cur_index_weight', 'target_index_weight','index_weight_diff',
                  'cur_index_mdd', 'cur_fund_mdd', 'fund_ex_index_ret_rate_recent_1m','relative_mdd', 'relative_mdd_day_length'
                 ]
-        pos_df = pos_df[df_cols_order].rename(columns=name_dic)
-        return pos_df
+        pos_df = pos_df[df_cols_order]
+        pos_df = pos_df.set_index('fund_id').join(_df).reset_index()
+        return pos_df.rename(columns=name_dic)
 
     def get_last_target_fund_allocation(self, target_fund):
         dt = list(self.fund_position_history.keys())[-1]
@@ -824,7 +827,11 @@ class ReportHelper:
         res_df = res_df.rename(columns={'ret':'fund_ret'})
         res_df['fund_ret'] = res_df.fund_ret.map(lambda x: str(round(x*100,2)) +'%')
         res_df['weight'] = res_df.weight.map(lambda x: str(round(x*100,2)) +'%')
-        return res_df[['begin_date','end_date','desc_name','index_id','fund_ret','weight','rets']]
+        res_df = res_df[['begin_date','end_date','desc_name','index_id','fund_ret','weight','rets']]
+        fund_id_list = res_df.index.tolist()
+        _df = m.view_data(func_name='get_daily_fund_daily_result', fund_id_list=fund_id_list).rename(columns={'基金ID':'fund_id'}).set_index('fund_id')
+        res_df = res_df.join(_df)
+        return res_df
 
     @staticmethod
     def rolling_analysis(rolling_year, index_id, m, mv_df, fund_annual_ret, ret_list=[]):
@@ -1048,4 +1055,286 @@ class ReportHelper:
         
         saa_df = pd.DataFrame([saa.__dict__],index=['weights']).replace(0,np.nan).dropna(axis=1).T
         AssetPainter.double_pie_chart(df_weight,saa_df)
-        return pos_weight.sort_values('wind_class_2')
\ No newline at end of file
+        return pos_weight.sort_values('wind_class_2')
+
+    def real_port_hold(self, check_date, port_name, m):
+        port_hold = {}
+        port_hold['稳健'] = {
+            'datetime':datetime.date(2020,11,23),
+            'position':[
+                    {
+                        'fund_id':'000860!0',
+                        'weight':0.085,
+                    },
+                    {
+                        'fund_id':'001931!0',
+                        'weight':0.085,
+                    },
+                    {
+                        'fund_id':'003042!0',
+                        'weight':0.085,
+                    },
+                    {
+                        'fund_id':'003999!0',
+                        'weight':0.165,
+                    },
+                    {
+                        'fund_id':'004449!0',
+                        'weight':0.085,
+                    },
+                    {
+                        'fund_id':'005893!0',
+                        'weight':0.165,
+                    },
+                    {
+                        'fund_id':'007333!0',
+                        'weight':0.165,
+                    },
+                    {
+                        'fund_id':'009404!0',
+                        'weight':0.165,
+                    },
+            ]
+        }
+
+        port_hold['进取'] = {
+            'datetime':datetime.date(2020,7,17),
+            'position':[
+                    {
+                        'fund_id':'161125!0',
+                        'weight':0.025,
+                    },
+                    {
+                        'fund_id':'164210!0',
+                        'weight':0.125,
+                    },
+                    {
+                        'fund_id':'673101!0',
+                        'weight':0.04,
+                    },
+                    {
+                        'fund_id':'000217!0',
+                        'weight':0.05,
+                    },
+                    {
+                        'fund_id':'000509!0',
+                        'weight':0.01,
+                    },
+                    {
+                        'fund_id':'000917!0',
+                        'weight':0.10,
+                    },
+                    {
+                        'fund_id':'002671!0',
+                        'weight':0.04,
+                    },
+                    {
+                        'fund_id':'002963!0',
+                        'weight':0.05,
+                    },
+                    {
+                        'fund_id':'004603!0',
+                        'weight':0.125,
+                    },
+                    {
+                        'fund_id':'005480!0',
+                        'weight':0.125,
+                    },
+                    {
+                        'fund_id':'006075!0',
+                        'weight':0.025,
+                    },
+                    {
+                        'fund_id':'006730!0',
+                        'weight':0.04,
+                    },
+                    {
+                        'fund_id':'006760!0',
+                        'weight':0.125,
+                    },
+                    {
+                        'fund_id':'006928!0',
+                        'weight':0.04,
+                    },
+                    {
+                        'fund_id':'007404!0',
+                        'weight':0.04,
+                    },
+                    {
+                        'fund_id':'008779!0',
+                        'weight':0.04,
+                    },
+            ]
+        }
+
+        port_hold['激进'] = {
+            'datetime':datetime.date(2021,1,12),
+            'position':[
+                    {
+                        'fund_id':'160424!0',
+                        'weight':0.04,
+                    },
+                    {
+                        'fund_id':'673101!0',
+                        'weight':0.05,
+                    },
+                    {
+                        'fund_id':'003999!0',
+                        'weight':0.09,
+                    },
+                    {
+                        'fund_id':'004449!0',
+                        'weight':0.095,
+                    },
+                    {
+                        'fund_id':'006075!0',
+                        'weight':0.05,
+                    },
+                    {
+                        'fund_id':'006730!0',
+                        'weight':0.05,
+                    },
+                    {
+                        'fund_id':'007333!0',
+                        'weight':0.094,
+                    },
+                    {
+                        'fund_id':'007404!0',
+                        'weight':0.05,
+                    },
+                    {
+                        'fund_id':'007465!0',
+                        'weight':0.04,
+                    },
+                    {
+                        'fund_id':'007795!0',
+                        'weight':0.05,
+                    },
+                    {
+                        'fund_id':'000701!0',
+                        'weight':0.055,
+                    },
+                    {
+                        'fund_id':'000931!0',
+                        'weight':0.09,
+                    },
+                    {
+                        'fund_id':'007045!0',
+                        'weight':0.05,
+                    },
+                    {
+                        'fund_id':'007386!0',
+                        'weight':0.05,
+                    },
+                    {
+                        'fund_id':'007448!0',
+                        'weight':0.05,
+                    },
+                    {
+                        'fund_id':'007829!0',
+                        'weight':0.096,
+                    },
+            ]
+        }
+
+        port_hold['年方二十'] = {
+            'datetime':datetime.date(2021,2,4),
+            'position':[
+                    {
+                        'fund_id':'160424!0',
+                        'weight':0.05,
+                    },
+                    {
+                        'fund_id':'202308!0',
+                        'weight':0.15,
+                    },
+                    {
+                        'fund_id':'001681!0',
+                        'weight':0.073,
+                    },
+                    {
+                        'fund_id':'003291!0',
+                        'weight':0.116,
+                    },
+                    {
+                        'fund_id':'006075!0',
+                        'weight':0.025,
+                    },
+                    {
+                        'fund_id':'006649!0',
+                        'weight':0.072,
+                    },
+                    {
+                        'fund_id':'007063!0',
+                        'weight':0.082,
+                    },
+                    {
+                        'fund_id':'007581!0',
+                        'weight':0.123,
+                    },
+                    {
+                        'fund_id':'007722!0',
+                        'weight':0.025,
+                    },
+                    {
+                        'fund_id':'004951!0',
+                        'weight':0.073,
+                    },
+                    {
+                        'fund_id':'005091!0',
+                        'weight':0.105,
+                    },
+                    {
+                        'fund_id':'005223!0',
+                        'weight':0.106,
+                    },
+            ]
+        }
+
+
+
+
+        fund_weight = pd.DataFrame(port_hold[port_name]['position']).set_index('fund_id')
+        start_date = port_hold[port_name]['datetime']
+        fund_nav = m.basic_data(func_name='get_fund_nav_with_date', fund_list=fund_weight.index.tolist(), start_date=start_date)
+        fund_nav = fund_nav.pivot_table(index='datetime',values='adjusted_net_value',columns='fund_id').ffill()
+        _fund_nav = fund_nav / fund_nav.iloc[0]
+        _fund_nav = _fund_nav * fund_weight.to_dict()['weight']
+        mv_df = pd.DataFrame(_fund_nav.loc[check_date:].sum(axis=1),columns=['mv'])
+        mv_df = mv_df.join(m.dts.index_price['hs300']).ffill().bfill()
+        mv_df = mv_df / mv_df.iloc[0]
+        
+        stats = Calculator.get_stat_result_from_df(df=mv_df.reset_index(), date_column='datetime', value_column='mv')
+        annual_ret= round(stats.annualized_ret,3)
+        mdd = round(stats.mdd,4)
+        total_ret = int((stats.last_unit_nav - 1) * 10000)
+        st = f'check period annual ret : {annual_ret} mdd : {mdd} total_ret {total_ret} bp'
+
+        port_bp_dict = round((mv_df.iloc[-1] - 1) * 10000, 1).to_dict()
+        bt_dict = ((fund_nav.iloc[-1] / fund_nav.loc[check_date]) - 1)*10000 
+        _dict = bt_dict * _fund_nav.loc[check_date]
+        _dict = _dict.round(1).to_dict()
+        _dict = {k: str(v)+'bp' for k, v in _dict.items()}
+        today = datetime.date.today()
+        FundPainter.plot_recent_ret(mv_df,check_date,today,st,port_name+' 盈米')
+        df = pd.DataFrame([_dict],index=['rets']).T
+        index_dic = m.dts.fund_index_map
+        index_dic['009404!0'] = 'national_debt'
+        index_dic['000701!0'] = 'mmf'
+        index_dic['001681!0'] = 'csi500'
+        index_dic['003291!0'] = 'hs300'
+        index_dic['007581!0'] = 'hs300'
+        df.loc[:,'begin_date'] = check_date
+        df.loc[:,'end_date'] = _fund_nav.index[-1]
+        df.loc[:,'desc_name'] = df.index.map(m.dts.fund_info.set_index('fund_id')['desc_name'])
+        df.loc[:,'fund_ret'] = (bt_dict / 100).round(2)
+        df.loc[:,'index_id'] = df.index.map(index_dic)
+        df.loc[:,'weight'] = df.index.map(_fund_nav.loc[check_date])
+        df = df.sort_values(by='fund_ret',ascending=False)
+        df['fund_ret'] = [str(i) + '%' for i in df['fund_ret']]
+        df['weight'] = [str(round((i*100),2)) + '%' for i in df['weight']]
+        df = df[['begin_date','end_date','desc_name','index_id','fund_ret','weight']]
+        fund_id_list = df.index.tolist()
+        _df = m.view_data(func_name='get_daily_fund_daily_result', fund_id_list=fund_id_list).rename(columns={'基金ID':'fund_id'}).set_index('fund_id')
+        df = df.join(_df)
+        return df
\ No newline at end of file
