@@ -122,8 +122,10 @@ class Calculator:
     @staticmethod
     def get_stat_result(dates: pandas.core.series.Series,
                         values: pandas.core.series.Series,
-                        frequency:str='1D'): #['1D','1W','2W','1M']
-        res = CalculatorBase.get_stat_result(dates=dates,values=values,frequency=frequency)
+                        frequency: str='1D',
+                        risk_free_rate: float=0.025,
+                        ): #['1D','1W','2W','1M']
+        res = CalculatorBase.get_stat_result(dates=dates,values=values,frequency=frequency,risk_free_rate=risk_free_rate)
         return SeriesStatUnit(
             start_date=res['start_date'],
             end_date=res['end_date'],
@@ -158,8 +160,10 @@ class Calculator:
     def get_benchmark_stat_result(dates: pandas.core.series.Series,
                                   values: pandas.core.series.Series,
                                   benchmark_values: pandas.core.series.Series,
-                                  frequency:str='1D'):#['1D','1W','2W','1M']
-        res = CalculatorBase.get_stat_result(dates=dates,values=values,benchmark_values=benchmark_values,frequency=frequency)
+                                  frequency:str='1D',
+                                  risk_free_rate: float=0.025,
+                                  ):#['1D','1W','2W','1M']
+        res = CalculatorBase.get_stat_result(dates=dates,values=values,benchmark_values=benchmark_values,frequency=frequency,risk_free_rate=risk_free_rate)
         return BenchmarkSeiesStatUnit(
             start_date=res['start_date'],
             end_date=res['end_date'],
@@ -246,9 +250,10 @@ class Calculator:
         stock_weights = DataManager.basic_data(func_name=f'get_fund_hold_{fund_type}_latest', fund_list = fund_list)
         stock_weights = stock_weights.set_index('fund_id').drop(columns=['datetime','_update_time'])
         weight_list = [i for i in stock_weights if 'weight' in i]
+        stock_weights = stock_weights.replace({None:np.nan})
         for r in stock_weights.iterrows():
             fund_id = r[0]
-            fund_weight = df.loc[fund_id, 'weight'] /100
+            fund_weight = df.loc[fund_id, 'weight']
             for weight_i in weight_list:
                 stock_weights.loc[fund_id, weight_i] = stock_weights.loc[fund_id, weight_i] / 100 * fund_weight
         _df = stock_weights.join(df)
@@ -265,8 +270,8 @@ class Calculator:
                 _res.append(dic)
         df = pandas.DataFrame(_res)
         df = pandas.merge(df,fund_info[['fund_id','desc_name']],on='fund_id')
-        _sum = df[f'{fund_type}_weight'].sum()
-        df[f'{fund_type}_weight'] = df[f'{fund_type}_weight'] / _sum
+        #_sum = df[f'{fund_type}_weight'].sum()
+        df[f'{fund_type}_weight'] = df[f'{fund_type}_weight']# / _sum
         df = df.sort_values(f'{fund_type}_weight',ascending=False)
 
         stock_list = df.stock_id.tolist()
@@ -305,11 +310,14 @@ class Calculator:
         stock_weights = DataManager.basic_data(func_name=f'get_fund_hold_{fund_type}_latest', fund_list = fund_list)
         stock_weights = stock_weights.set_index('fund_id').drop(columns=['datetime','_update_time'])
         weight_list = [i for i in stock_weights if 'weight' in i]
+        stock_weights = stock_weights.replace({None:np.nan})
         for r in stock_weights.iterrows():
             fund_id = r[0]
-            fund_weight = df.loc[fund_id, 'weight'] /100
+            fund_weight = df.loc[fund_id, 'weight']
             for weight_i in weight_list:
-                stock_weights.loc[fund_id, weight_i] = stock_weights.loc[fund_id, weight_i] / 100 * fund_weight
+                stock_w = stock_weights.loc[fund_id, weight_i]
+                stock_weights.loc[fund_id, weight_i] = stock_w / 100 * fund_weight
+        
         _df = stock_weights.join(df)
         _res = []
         for r in stock_weights.iterrows():
@@ -337,8 +345,8 @@ class Calculator:
         conv_bond_info.loc[:,'cbl1_type'] = '可转债'
         bond_info.loc[:,'cbl1_type'] = bond_info.cbl1_type.map(lambda x: x.replace('(中债)','').replace('（中债）',''))
         df = df.join(bond_info[['bond_id','cbl1_type']].append(conv_bond_info[['bond_id','cbl1_type']]).set_index('bond_id'), on='bond_id')
-        _sum = df[f'{fund_type}_weight'].sum()
-        df[f'{fund_type}_weight'] = df[f'{fund_type}_weight'] / _sum
+        #_sum = df[f'{fund_type}_weight'].sum()
+        df[f'{fund_type}_weight'] = df[f'{fund_type}_weight']# / _sum
         df = df.sort_values(f'{fund_type}_weight',ascending=False)
         today = datetime.datetime.now().date()
         td = (df.maturity - today)
