@@ -35,7 +35,9 @@ class CalculatorBase:
             'm3': DateOffset(months=3),
             'm6': DateOffset(months=6),
             'y1': DateOffset(years=1),
+            'y2': DateOffset(years=2),
             'y3': DateOffset(years=3),
+            'y4': DateOffset(years=4),
             'y5': DateOffset(years=5),
         }
         last_date = datetime.datetime.now().date()
@@ -44,7 +46,7 @@ class CalculatorBase:
             if name == 'w1':
                 bd = (week_end_date - value).date()
             else:
-                bd = (last_date - value).date()
+                bd = (week_end_date - value).date()
             begin_date_dic[name] = bd
         return last_date, begin_date_dic
 
@@ -124,13 +126,21 @@ class CalculatorBase:
         _begin_date = sr.index[0]
         _natural_year_begin_date = datetime.date(last_date.year,1,1)
         recent_natural_year_ret = sr.loc[:last_date][-1] / sr.loc[:max(_natural_year_begin_date,_begin_date)][-1] - 1
-        recent_1w_ret = sr.loc[:last_date][-1] / sr.loc[:max(begin_date_dic['w1'],_begin_date)][-1] - 1
-        recent_1m_ret = sr.loc[:last_date][-1] / sr.loc[:max(begin_date_dic['m1'],_begin_date)][-1] - 1
-        recent_3m_ret = sr.loc[:last_date][-1] / sr.loc[:max(begin_date_dic['m3'],_begin_date)][-1] - 1
-        recent_6m_ret = sr.loc[:last_date][-1] / sr.loc[:max(begin_date_dic['m6'],_begin_date)][-1] - 1
-        recent_1y_ret = sr.loc[:last_date][-1] / sr.loc[:max(begin_date_dic['y1'],_begin_date)][-1] - 1
-        recent_3y_ret = sr.loc[:last_date][-1] / sr.loc[:max(begin_date_dic['y3'],_begin_date)][-1] - 1
-        recent_5y_ret = sr.loc[:last_date][-1] / sr.loc[:max(begin_date_dic['y5'],_begin_date)][-1] - 1
+        _res = {}
+        for _period, _period_begin_date in begin_date_dic.items():
+            if _period_begin_date >= _begin_date and sr.index[-1] > _period_begin_date:
+                _res[_period] = sr.loc[:last_date][-1] / sr.loc[_period_begin_date:][0] - 1
+            else:
+                _res[_period] = np.nan
+        recent_1w_ret = _res['w1']
+        recent_1m_ret = _res['m1']
+        recent_3m_ret = _res['m3']
+        recent_6m_ret = _res['m6']
+        recent_1y_ret = _res['y1']
+        recent_2y_ret = _res['y2']
+        recent_3y_ret = _res['y3']
+        recent_4y_ret = _res['y4']
+        recent_5y_ret = _res['y5']
         history_ret = sr.loc[:last_date][-1] / sr[0] - 1
         days = (dates[-1] - dates[0]).days
         history_annual_ret = math.pow(history_ret + 1, CalculatorBase.TOTAL_DAYS_PER_YEAR/days) - 1
@@ -142,7 +152,9 @@ class CalculatorBase:
             'recent_3m_ret':recent_3m_ret,
             'recent_6m_ret':recent_6m_ret,
             'recent_1y_ret':recent_1y_ret,
+            'recent_2y_ret':recent_2y_ret,
             'recent_3y_ret':recent_3y_ret,
+            'recent_4y_ret':recent_4y_ret,
             'recent_5y_ret':recent_5y_ret,
             'history_ret':history_ret,
             'history_annual_ret':history_annual_ret,
